@@ -84,6 +84,8 @@ def create_video(list_comp_data, path_video, job_id):
         final_clip.write_videofile(path_video, fps=24, codec='libx264', logger=logger)
         final_clip.close()
     else:
+        if audio_compilation_path is None:
+            raise Exception("Audio Compulation Error!!!")
         cnt_real_duration=0
         while max_real_duration < 60*2/3 and cnt_real_duration<2:
             max_real_duration*=2
@@ -91,17 +93,20 @@ def create_video(list_comp_data, path_video, job_id):
         tmp_path = get_dir('coolbg_ffmpeg') + str(uuid.uuid4()) +".avi"
         tmp_path_maked_loop = get_dir('coolbg_ffmpeg') + str(uuid.uuid4()) + ".avi"
         final_clip = CompositeVideoClip(arr_composite).subclip(0, max_real_duration)
-        final_clip.write_videofile(tmp_path, fps=24, codec='libx264', logger=logger)
+        final_clip.write_videofile(tmp_path, fps=24, codec='libx264',audio=False)
         final_clip.close()
         final_clip = VideoFileClip(tmp_path, audio=False)
         cross = final_clip.duration / 5
         if cross > 3:
             cross = 3
         clip = make_loopable.make_loopable(final_clip, cross)
-        clip.write_videofile(tmp_path_maked_loop, fps=24, codec='libx264', logger=logger)
+        clip.write_videofile(tmp_path_maked_loop, fps=24, codec='libx264',audio=False)
         clip.close()
+        final_clip.close()
         audio_compilation = AudioFileClip(audio_compilation_path)
         final_clip_path = create_loop(tmp_path_maked_loop, audio_compilation.duration)
+        os.remove(tmp_path_maked_loop)
+        os.remove(tmp_path)
         audio_compilation.close()
         create_video_audio(final_clip_path, audio_compilation_path, path_video)
 
